var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

/*
 * This file is part of the nivo project.
 *
 * Copyright 2016-present, Raphaël Benitte.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
import React from 'react';
import { getColorRange } from '../../../lib/colors';
import Container from '../Container';
import SvgWrapper from '../SvgWrapper';
import enhance from './enhance';
import { ChordPropTypes } from './props';
import ChordRibbons from './ChordRibbons';
import ChordArcs from './ChordArcs';

var Chord = function Chord(_ref) {
    var matrix = _ref.matrix,
        keys = _ref.keys,
        margin = _ref.margin,
        width = _ref.width,
        height = _ref.height,
        outerWidth = _ref.outerWidth,
        outerHeight = _ref.outerHeight,
        ribbonOpacity = _ref.ribbonOpacity,
        ribbonBorderWidth = _ref.ribbonBorderWidth,
        arcOpacity = _ref.arcOpacity,
        arcBorderWidth = _ref.arcBorderWidth,
        chord = _ref.chord,
        arcGenerator = _ref.arcGenerator,
        ribbonGenerator = _ref.ribbonGenerator,
        theme = _ref.theme,
        colors = _ref.colors,
        isInteractive = _ref.isInteractive,
        arcHoverOpacity = _ref.arcHoverOpacity,
        arcHoverOthersOpacity = _ref.arcHoverOthersOpacity,
        ribbonHoverOpacity = _ref.ribbonHoverOpacity,
        ribbonHoverOthersOpacity = _ref.ribbonHoverOthersOpacity,
        animate = _ref.animate,
        motionDamping = _ref.motionDamping,
        motionStiffness = _ref.motionStiffness,
        currentArc = _ref.currentArc,
        setCurrentArc = _ref.setCurrentArc,
        currentRibbon = _ref.currentRibbon,
        setCurrentRibbon = _ref.setCurrentRibbon;

    var centerX = width / 2;
    var centerY = height / 2;

    var color = getColorRange(colors);

    var colorById = keys.reduce(function (acc, key) {
        acc[key] = color(key);
        return acc;
    }, {});

    var ribbons = chord(matrix);
    ribbons.forEach(function (ribbon) {
        ribbon.source.id = keys[ribbon.source.index];
        ribbon.source.color = colorById[ribbon.source.id];
        ribbon.target.id = keys[ribbon.target.index];
        ribbon.target.color = colorById[ribbon.target.id];
        var ribbonKeys = [ribbon.source.id, ribbon.target.id];
        ribbonKeys.sort();
        ribbon.key = ribbonKeys.sort().join('.');
    });

    var arcs = ribbons.groups.map(function (arc) {
        arc.key = arc.id = keys[arc.index];
        arc.color = colorById[arc.id];
        return arc;
    });

    var getArcOpacity = function getArcOpacity() {
        return arcOpacity;
    };
    var getRibbonOpacity = function getRibbonOpacity() {
        return ribbonOpacity;
    };
    if (isInteractive) {
        if (currentArc) {
            getArcOpacity = function getArcOpacity(arc) {
                if (arc.id === currentArc.id) return arcHoverOpacity;
                return arcHoverOthersOpacity;
            };
            getRibbonOpacity = function getRibbonOpacity(ribbon) {
                if (ribbon.source.id === currentArc.id) return ribbonHoverOpacity;
                return ribbonHoverOthersOpacity;
            };
        } else if (currentRibbon) {
            getArcOpacity = function getArcOpacity(arc) {
                if (arc.id === currentRibbon.source.id || arc.id === currentRibbon.target.id) return arcHoverOpacity;
                return arcHoverOthersOpacity;
            };
            getRibbonOpacity = function getRibbonOpacity(ribbon) {
                if (ribbon.source.id === currentRibbon.source.id && ribbon.target.id === currentRibbon.target.id) return ribbonHoverOpacity;
                return ribbonHoverOthersOpacity;
            };
        }
    }

    var motionProps = {
        animate: animate,
        motionDamping: motionDamping,
        motionStiffness: motionStiffness
    };

    return React.createElement(
        Container,
        { isInteractive: isInteractive, theme: theme },
        function (_ref2) {
            var showTooltip = _ref2.showTooltip,
                hideTooltip = _ref2.hideTooltip;

            return React.createElement(
                SvgWrapper,
                { width: outerWidth, height: outerHeight, margin: margin },
                React.createElement(
                    'g',
                    { transform: 'translate(' + centerX + ', ' + centerY + ')' },
                    React.createElement(ChordRibbons, _extends({
                        ribbons: ribbons,
                        shapeGenerator: ribbonGenerator,
                        borderWidth: ribbonBorderWidth,
                        getOpacity: getRibbonOpacity,
                        setCurrent: setCurrentRibbon,
                        theme: theme,
                        showTooltip: showTooltip,
                        hideTooltip: hideTooltip
                    }, motionProps)),
                    React.createElement(ChordArcs, _extends({
                        arcs: arcs,
                        shapeGenerator: arcGenerator,
                        borderWidth: arcBorderWidth,
                        getOpacity: getArcOpacity,
                        setCurrent: setCurrentArc,
                        theme: theme,
                        showTooltip: showTooltip,
                        hideTooltip: hideTooltip
                    }, motionProps))
                )
            );
        }
    );
};

Chord.propTypes = ChordPropTypes;

export default enhance(Chord);