var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

/*
 * This file is part of the nivo project.
 *
 * Copyright 2016-present, Raphaël Benitte.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
import React from 'react';
import PropTypes from 'prop-types';
import { TransitionMotion, spring } from 'react-motion';
import { colorMotionSpring, getInterpolatedColor } from '../../../lib/colors';
import { midAngle } from '../../../lib/arcUtils';
import TableTooltip from '../../tooltip/TableTooltip';
import Chip from '../../tooltip/Chip';

var ribbonWillEnter = function ribbonWillEnter(_ref) {
    var ribbon = _ref.data;

    var sourceMidAngle = midAngle(ribbon.source);
    var targetMidAngle = midAngle(ribbon.target);

    return _extends({
        sourceStartAngle: sourceMidAngle,
        sourceEndAngle: sourceMidAngle,
        targetStartAngle: targetMidAngle,
        targetEndAngle: targetMidAngle,
        opacity: 0
    }, colorMotionSpring(ribbon.source.color));
};

var ribbonWillLeave = function ribbonWillLeave(springConfig) {
    return function (_ref2) {
        var ribbon = _ref2.data;

        var sourceMidAngle = midAngle(ribbon.source);
        var targetMidAngle = midAngle(ribbon.target);

        return _extends({
            sourceStartAngle: spring(sourceMidAngle, springConfig),
            sourceEndAngle: spring(sourceMidAngle, springConfig),
            targetStartAngle: spring(targetMidAngle, springConfig),
            targetEndAngle: spring(targetMidAngle, springConfig),
            opacity: 0
        }, colorMotionSpring(ribbon.source.color, springConfig));
    };
};

var ChordRibbons = function ChordRibbons(_ref3) {
    var ribbons = _ref3.ribbons,
        shapeGenerator = _ref3.shapeGenerator,
        ribbonBorderWidth = _ref3.ribbonBorderWidth,
        getOpacity = _ref3.getOpacity,
        theme = _ref3.theme,
        setCurrent = _ref3.setCurrent,
        showTooltip = _ref3.showTooltip,
        hideTooltip = _ref3.hideTooltip,
        animate = _ref3.animate,
        motionDamping = _ref3.motionDamping,
        motionStiffness = _ref3.motionStiffness;

    var commonProps = function commonProps(ribbon) {
        var ribbonTooltip = React.createElement(TableTooltip, {
            theme: theme,
            rows: [[React.createElement(Chip, { color: ribbon.source.color }), React.createElement(
                'strong',
                null,
                ribbon.source.id
            ), ribbon.source.value], [React.createElement(Chip, { color: ribbon.target.color }), React.createElement(
                'strong',
                null,
                ribbon.target.id
            ), ribbon.target.value]]
        });

        return {
            strokeWidth: ribbonBorderWidth,
            onMouseEnter: function onMouseEnter(e) {
                setCurrent(ribbon);
                showTooltip(ribbonTooltip, e);
            },
            onMouseMove: function onMouseMove(e) {
                showTooltip(ribbonTooltip, e);
            },
            onMouseLeave: function onMouseLeave() {
                setCurrent(null);
                hideTooltip();
            }
        };
    };

    if (animate !== true) {
        return React.createElement(
            'g',
            null,
            ribbons.map(function (ribbon) {
                var opacity = getOpacity(ribbon);

                return React.createElement('path', _extends({
                    key: ribbon.key,
                    d: shapeGenerator(ribbon),
                    fill: ribbon.source.color,
                    fillOpacity: opacity,
                    stroke: ribbon.source.color,
                    strokeOpacity: opacity
                }, commonProps(ribbon)));
            })
        );
    }

    var springConfig = {
        damping: motionDamping,
        stiffness: motionStiffness
    };

    return React.createElement(
        TransitionMotion,
        {
            willEnter: ribbonWillEnter,
            willLeave: ribbonWillLeave(springConfig),
            styles: ribbons.map(function (ribbon) {
                return {
                    key: ribbon.key,
                    data: ribbon,
                    style: _extends({
                        sourceStartAngle: spring(ribbon.source.startAngle, springConfig),
                        sourceEndAngle: spring(ribbon.source.endAngle, springConfig),
                        targetStartAngle: spring(ribbon.target.startAngle, springConfig),
                        targetEndAngle: spring(ribbon.target.endAngle, springConfig),
                        opacity: spring(getOpacity(ribbon), springConfig)
                    }, colorMotionSpring(ribbon.source.color, springConfig))
                };
            })
        },
        function (interpolatedStyles) {
            return React.createElement(
                'g',
                null,
                interpolatedStyles.map(function (_ref4) {
                    var key = _ref4.key,
                        style = _ref4.style,
                        ribbon = _ref4.data;

                    var color = getInterpolatedColor(style);

                    return React.createElement('path', _extends({
                        key: key,
                        d: shapeGenerator({
                            source: {
                                startAngle: style.sourceStartAngle,
                                endAngle: style.sourceEndAngle
                            },
                            target: {
                                startAngle: style.targetStartAngle,
                                endAngle: style.targetEndAngle
                            }
                        }),
                        fill: color,
                        fillOpacity: style.opacity,
                        stroke: color,
                        strokeOpacity: style.opacity
                    }, commonProps(ribbon)));
                })
            );
        }
    );
};

ChordRibbons.propTypes = {
    ribbons: PropTypes.array.isRequired,
    shapeGenerator: PropTypes.func.isRequired,
    borderWidth: PropTypes.number.isRequired,
    getOpacity: PropTypes.func.isRequired,
    setCurrent: PropTypes.func.isRequired,
    theme: PropTypes.object.isRequired,
    showTooltip: PropTypes.func.isRequired,
    hideTooltip: PropTypes.func.isRequired
};

export default ChordRibbons;