/*
 * This file is part of the nivo project.
 *
 * Copyright 2016-present, Raphaël Benitte.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
import compose from 'recompose/compose';
import defaultProps from 'recompose/defaultProps';
import withState from 'recompose/withState';
import withPropsOnChange from 'recompose/withPropsOnChange';
import pure from 'recompose/pure';
import { arc as d3Arc } from 'd3-shape';
import { chord as d3Chord, ribbon as d3Ribbon } from 'd3-chord';
import { withMotion, withTheme, withDimensions } from '../../../hocs';
import { ChordDefaultProps } from './props';

export default (function (Component) {
    return compose(defaultProps(ChordDefaultProps), withState('currentArc', 'setCurrentArc', null), withState('currentRibbon', 'setCurrentRibbon', null), withMotion(), withTheme(), withDimensions(), withPropsOnChange(['padAngle'], function (_ref) {
        var padAngle = _ref.padAngle;
        return {
            chord: d3Chord().padAngle(padAngle)
        };
    }), withPropsOnChange(['width', 'height', 'innerRadiusRatio', 'innerRadiusOffset'], function (_ref2) {
        var width = _ref2.width,
            height = _ref2.height,
            innerRadiusRatio = _ref2.innerRadiusRatio,
            innerRadiusOffset = _ref2.innerRadiusOffset;

        var radius = Math.min(width, height) / 2;
        var ribbonRadius = radius * (innerRadiusRatio - innerRadiusOffset);

        var arcGenerator = d3Arc().outerRadius(radius).innerRadius(radius * innerRadiusRatio);
        var ribbonGenerator = d3Ribbon().radius(ribbonRadius);

        return { radius: radius, arcGenerator: arcGenerator, ribbonGenerator: ribbonGenerator };
    }), pure)(Component);
});